MatchMakerActivation
==========================================

.. currentmodule:: alfred3_interact.page

.. autoclass:: MatchMakerActivation
   :show-inheritance:




   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
      :toctree:




      ~MatchMakerActivation.added_to_experiment


      ~MatchMakerActivation.added_to_section


      ~MatchMakerActivation.append


      ~MatchMakerActivation.close


      ~MatchMakerActivation.custom_move


      ~MatchMakerActivation.durations


      ~MatchMakerActivation.first_duration


      ~MatchMakerActivation.last_duration


      ~MatchMakerActivation.on_close


      ~MatchMakerActivation.on_each_hide


      ~MatchMakerActivation.on_each_show


      ~MatchMakerActivation.on_exp_access


      ~MatchMakerActivation.on_first_hide


      ~MatchMakerActivation.on_first_show


      ~MatchMakerActivation.position_in_section


      ~MatchMakerActivation.prepare_web_widget


      ~MatchMakerActivation.save_data


      ~MatchMakerActivation.showif


      ~MatchMakerActivation.uptree


      ~MatchMakerActivation.validate


      ~MatchMakerActivation.visible







   .. rubric:: Attributes

   .. autosummary::
      :template: autosummary/attribute.rst
      :toctree:


         ~MatchMakerActivation.access_level
         ~MatchMakerActivation.all_elements
         ~MatchMakerActivation.all_input_elements
         ~MatchMakerActivation.background_color
         ~MatchMakerActivation.data
         ~MatchMakerActivation.elements
         ~MatchMakerActivation.exp
         ~MatchMakerActivation.experiment
         ~MatchMakerActivation.filled_input_elements
         ~MatchMakerActivation.fixed_width
         ~MatchMakerActivation.footer_text
         ~MatchMakerActivation.has_been_shown
         ~MatchMakerActivation.header_color
         ~MatchMakerActivation.input_elements
         ~MatchMakerActivation.instance_log
         ~MatchMakerActivation.is_closed
         ~MatchMakerActivation.minimum_display_time
         ~MatchMakerActivation.minimum_display_time_msg
         ~MatchMakerActivation.must_be_shown
         ~MatchMakerActivation.name
         ~MatchMakerActivation.parent
         ~MatchMakerActivation.parent_name
         ~MatchMakerActivation.prefix_element_names
         ~MatchMakerActivation.progress
         ~MatchMakerActivation.responsive_width
         ~MatchMakerActivation.section
         ~MatchMakerActivation.short_tree
         ~MatchMakerActivation.should_be_shown
         ~MatchMakerActivation.subtitle
         ~MatchMakerActivation.tag
         ~MatchMakerActivation.title
         ~MatchMakerActivation.tree
         ~MatchMakerActivation.uid
         ~MatchMakerActivation.unlinked_data
         ~MatchMakerActivation.updated_elements
         ~MatchMakerActivation.vargs
